(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     35083,       1072]
NotebookOptionsPosition[     29117,        972]
NotebookOutlinePosition[     29727,        995]
CellTagsIndexPosition[     29684,        992]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 6, Section 6.11", "Section",ExpressionUUID->"7caaa5d9-326a-481c-9bd0-4d8640893aea"],

Cell["\<\
We start by deriving explicit expressions for the Legendre polynomials of \
degree 2 in terms of Sin[\[Alpha]] (see Eq.(6.252)) ...\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"65d60a7e-9249-443f-bdc0-d47eb406649d"],

Cell[CellGroupData[{

Cell["p2 = LegendreP[2,Sin[\[Alpha]]]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"6e7d6b93-3fa0-4fd8-8131-3cdb364d2a09"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    RowBox[{"3", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Alpha]", "]"}], "2"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.811324657811129*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"ccbecf64-e43e-4c63-99b1-d088ca42fe87"]
}, Open  ]],

Cell["... and degree 4 (see Eq.(6.253)).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2d49be88-e574-4f44-b6fe-d06eac99ae02"],

Cell[CellGroupData[{

Cell["p4 = LegendreP[4,Sin[\[Alpha]]]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"0860c9c1-4ecd-4c7e-b2ea-cd6b4e834718"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", "8"], " ", 
  RowBox[{"(", 
   RowBox[{"3", "-", 
    RowBox[{"30", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Alpha]", "]"}], "2"]}], "+", 
    RowBox[{"35", " ", 
     SuperscriptBox[
      RowBox[{"Sin", "[", "\[Alpha]", "]"}], "4"]}]}], ")"}]}]], "Output",
 CellChangeTimes->{3.811324657914466*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"d8a333b5-12e5-4cac-9e32-f875570d399e"]
}, Open  ]],

Cell["\<\
Use the substitution given in Eq.(6.254) and expand the resulting expressions.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c3061a05-3a49-404b-8deb-bd60c473c520"],

Cell[CellGroupData[{

Cell["ps2 = Expand[p2 /. {Sin[\[Alpha]]->si*(sf*cw+cf*sw)}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"ba3dba41-dd3a-4ebe-bc05-173022f18487"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox["1", "2"]}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox["cw", "2"], " ", 
   SuperscriptBox["sf", "2"], " ", 
   SuperscriptBox["si", "2"]}], "+", 
  RowBox[{"3", " ", "cf", " ", "cw", " ", "sf", " ", 
   SuperscriptBox["si", "2"], " ", "sw"}], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", 
   SuperscriptBox["cf", "2"], " ", 
   SuperscriptBox["si", "2"], " ", 
   SuperscriptBox["sw", "2"]}]}]], "Output",
 CellChangeTimes->{3.811324657918951*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"8dd1a26c-842f-4e9e-badb-1854f870cc92"]
}, Open  ]],

Cell[CellGroupData[{

Cell["ps4 = Expand[p4 /. {Sin[\[Alpha]]->si*(sf*cw+cf*sw)}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"ab6bcb1c-d47c-41a7-bdd3-634f7479a267"],

Cell[BoxData[
 RowBox[{
  FractionBox["3", "8"], "-", 
  RowBox[{
   FractionBox["15", "4"], " ", 
   SuperscriptBox["cw", "2"], " ", 
   SuperscriptBox["sf", "2"], " ", 
   SuperscriptBox["si", "2"]}], "+", 
  RowBox[{
   FractionBox["35", "8"], " ", 
   SuperscriptBox["cw", "4"], " ", 
   SuperscriptBox["sf", "4"], " ", 
   SuperscriptBox["si", "4"]}], "-", 
  RowBox[{
   FractionBox["15", "2"], " ", "cf", " ", "cw", " ", "sf", " ", 
   SuperscriptBox["si", "2"], " ", "sw"}], "+", 
  RowBox[{
   FractionBox["35", "2"], " ", "cf", " ", 
   SuperscriptBox["cw", "3"], " ", 
   SuperscriptBox["sf", "3"], " ", 
   SuperscriptBox["si", "4"], " ", "sw"}], "-", 
  RowBox[{
   FractionBox["15", "4"], " ", 
   SuperscriptBox["cf", "2"], " ", 
   SuperscriptBox["si", "2"], " ", 
   SuperscriptBox["sw", "2"]}], "+", 
  RowBox[{
   FractionBox["105", "4"], " ", 
   SuperscriptBox["cf", "2"], " ", 
   SuperscriptBox["cw", "2"], " ", 
   SuperscriptBox["sf", "2"], " ", 
   SuperscriptBox["si", "4"], " ", 
   SuperscriptBox["sw", "2"]}], "+", 
  RowBox[{
   FractionBox["35", "2"], " ", 
   SuperscriptBox["cf", "3"], " ", "cw", " ", "sf", " ", 
   SuperscriptBox["si", "4"], " ", 
   SuperscriptBox["sw", "3"]}], "+", 
  RowBox[{
   FractionBox["35", "8"], " ", 
   SuperscriptBox["cf", "4"], " ", 
   SuperscriptBox["si", "4"], " ", 
   SuperscriptBox["sw", "4"]}]}]], "Output",
 CellChangeTimes->{3.811324657923099*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"6ff42e85-3174-4fbb-ba8c-37a82353b469"]
}, Open  ]],

Cell[TextData[{
 "Use Eq.(6.244) to derive an expression for \[ScriptCapitalG]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", 
    StyleBox["p",
     FontSlant->"Plain"]], TraditionalForm]],ExpressionUUID->
  "206c0555-a460-4d25-9b2b-206655faf33f"]
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"51be784b-9377-4efe-bfa9-7a8562dcdfc0"],

Cell[CellGroupData[{

Cell["\<\
gmp = 
Normal[Series[
n^2*a^3/(1+(3/2)*J2*(Rpoa)^2-
 (15/8)*J4*(Rpoa)^4),{Rpoa,0,4}]] /. {Rpoa->Rp/a}\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"bfefa771-aaf3-4708-8e39-6df0ea4596a7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["a", "3"], " ", 
   SuperscriptBox["n", "2"]}], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", "a", " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"6", " ", 
       SuperscriptBox["J2", "2"]}], "+", 
      RowBox[{"5", " ", "J4"}]}], ")"}], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", "a"}]]}]], "Output",
 CellChangeTimes->{3.811324657967556*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"27e7f37f-4db6-4a66-97d7-1896fe2f62a4"]
}, Open  ]],

Cell["\<\
Now use these expressions to derive an expression for \[ScriptCapitalR] as \
defined in Eq.(6.251). \
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"107328aa-f9ff-4fd1-ad44-5cccff885735"],

Cell["\<\
bigR = 
-GM*(J2*Rp^2/r^3*ps2 +J4*Rp^4/r^5*ps4) /. 
{r->a(1-e^2)/(1+e*cf), GM->gmp};\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"ae499171-16a5-41e4-a752-5f5d5663d391"],

Cell[TextData[{
 "Substitute the series for Sin[",
 StyleBox["f",
  FontSlant->"Italic"],
 "] and Cos[",
 StyleBox["f",
  FontSlant->"Italic"],
 "] (to second order in the eccentricity) as given by Eqs.(2.84) and (2.85)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e18473ed-f6e3-4fed-8f7c-ca0a9011d71a"],

Cell["\<\
bigR = bigR /. 
{sf->Sin[M]+e*Sin[2M]+e^2((9/8)*Sin[3M]-(7/8)*Sin[M]),
 cf->Cos[M]+e*(Cos[2M]-1)+(9/8)*e^2*(Cos[3M]-Cos[M])};\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"9eb27eb7-49ac-4316-92cf-5344a1972a65"],

Cell[TextData[{
 "Expand the result as a series in ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and Sin[",
 StyleBox["I",
  FontSlant->"Italic"],
 "] to second order."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"19644444-e1cc-4164-b953-a33c31ead15a"],

Cell["\<\
tbigR = 
Normal[Series[(bigR /. {e->t*e, si->t*si}), {t,0,2}]] /. {t->1};\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"ff5dc4e4-ed9d-4524-ba45-805e49753b33"],

Cell[TextData[{
 "Now expand this as a series in ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", 
     StyleBox["p",
      FontSlant->"Plain"]], "/", "a"}], TraditionalForm]],ExpressionUUID->
  "b36fbeba-4ccb-4458-8330-e6f4cfe01c59"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d675f371-36b8-4f68-94ea-1a34afb111ac"],

Cell[CellGroupData[{

Cell["tbigR=TrigReduce[Normal[Series[tbigR,{Rp,0,4}]]]", "Input",
 CellLabel->"In[9]:=",ExpressionUUID->"50af5afb-b4fb-4daa-a5a2-c12debaff2b7"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["e", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["e", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["cw", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["cw", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["cw", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"], " ", 
   SuperscriptBox["sw", "2"]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    SuperscriptBox["sw", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    SuperscriptBox["sw", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  RowBox[{
   FractionBox["3", "2"], " ", "e", " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   RowBox[{"Cos", "[", "M", "]"}]}], "-", 
  FractionBox[
   RowBox[{"9", " ", "e", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    RowBox[{"Cos", "[", "M", "]"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", "e", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    RowBox[{"Cos", "[", "M", "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  RowBox[{
   FractionBox["9", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"27", " ", 
    SuperscriptBox["e", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["e", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["cw", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["cw", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["cw", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"], " ", 
   SuperscriptBox["sw", "2"], " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    SuperscriptBox["sw", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", 
    SuperscriptBox["sw", "2"], " ", 
    RowBox[{"Cos", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  RowBox[{
   FractionBox["3", "2"], " ", "cw", " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"], " ", "sw", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2", " ", "M"}], "]"}]}], "+", 
  FractionBox[
   RowBox[{"9", " ", "cw", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", "sw", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", "cw", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"], " ", "sw", " ", 
    RowBox[{"Sin", "[", 
     RowBox[{"2", " ", "M"}], "]"}]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324658164366*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"3f406dad-d171-4c1c-9a36-cee9708437a5"]
}, Open  ]],

Cell[TextData[{
 "Now that we have a series in the mean anomaly we can carry out a time \
average of this expression.  Note that the result has terms in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],ExpressionUUID->
  "62f03740-ba42-4baf-882f-954efa3a6e07"],
 "and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["s", "2"], TraditionalForm]],ExpressionUUID->
  "06971353-bcf7-4a85-b350-3685a18478f6"],
 "as well as terms which are independent of ",
 StyleBox["e",
  FontSlant->"Italic"],
 " and ",
 StyleBox["s",
  FontSlant->"Italic"],
 " and are effectively constant"
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1240bea7-5e85-4685-80c3-6d4844ce7b2f"],

Cell[CellGroupData[{

Cell["\<\
avbigR = 
Expand[Integrate[tbigR/2/Pi, {M,0,2Pi}] /. 
{cw^2->1-sw^2}]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"d824dfb7-6448-4910-b295-126518573e6a"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["1", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"4", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["e", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["e", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.8113246588668327`*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"30fe53ca-0b86-417f-a3ff-6fa2b5236683"]
}, Open  ]],

Cell[TextData[{
 "Isolate the terms in eccentricity  (see the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["e", "2"], TraditionalForm]],ExpressionUUID->
  "51391831-9186-45ab-8ff9-b0823c676f5a"],
 "terms in Eq.(6.255)) ..."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"33959b73-6e1e-4d7d-ba96-af4a5461cf15"],

Cell[CellGroupData[{

Cell["eterm = Coefficient[avbigR, e, 2]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"12fe8563-f178-44aa-9d8b-3ff280a19146"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324658976596*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"f19e5233-d0fe-4f6a-829f-e57f62e91b75"]
}, Open  ]],

Cell[TextData[{
 "... and inclination  (see the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["s", "2"], TraditionalForm]],ExpressionUUID->
  "74aff6b4-ad5a-45b8-bfe1-be675641eed8"],
 "terms in Eq.(6.255))."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6a30b261-e286-43b8-9678-5e7dea15ce0d"],

Cell[CellGroupData[{

Cell["iterm = Coefficient[avbigR, si, 2]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"9eb5dfdd-0f61-4682-aa5e-c6a64f7bf1d6"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "4"]}], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324658981365*^9},
 CellLabel->"Out[12]=",ExpressionUUID->"30cb87f2-363a-442e-9033-25a97a035fcb"]
}, Open  ]],

Cell["The remaining terms are the \"constant\" part.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"1d2ed81a-25e2-4a5a-87d1-64af5b3cd958"],

Cell[CellGroupData[{

Cell["Expand[final - e^2*eterm - si^2*iterm]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"89285985-34ad-4317-8d33-366230d82ffd"],

Cell[BoxData[
 RowBox[{"final", "-", 
  RowBox[{
   FractionBox["3", "4"], " ", 
   SuperscriptBox["e", "2"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["e", "2"], " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  FractionBox[
   RowBox[{"15", " ", 
    SuperscriptBox["e", "2"], " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "+", 
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n", "2"], " ", 
   SuperscriptBox["Rp", "2"], " ", 
   SuperscriptBox["si", "2"]}], "-", 
  FractionBox[
   RowBox[{"9", " ", 
    SuperscriptBox["J2", "2"], " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n", "2"], " ", 
    SuperscriptBox["Rp", "4"], " ", 
    SuperscriptBox["si", "2"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324659025823*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"48cef4c2-bdb9-4e45-8567-932a99a471bf"]
}, Open  ]],

Cell[TextData[{
 "Our expressions for ",
 StyleBox["eterm", "Input"],
 " and ",
 StyleBox["iterm", "Input"],
 " are both in terms of ",
 StyleBox["n", "Input"],
 ", the actual mean motion (including the effects of oblateness) rather than ",
 StyleBox["n0", "Input"],
 ", the nominal, keplerian mean motion.  So we use the relationaship given in \
Eq.(6.244) to express ",
 StyleBox["eterm", "Input"],
 " as a series in terms of ",
 StyleBox["n0", "Input"],
 ".  "
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fad55690-c4de-49e1-adbb-f342d21684f0"],

Cell[CellGroupData[{

Cell["\<\
Normal[Series[
eterm /. {n^2->n0^2*(1+(3/2)*J2*(Rp/a)^2-(15/8)*J4*(Rp/a)^4)},
{Rp,0,4}]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"800c0797-35ae-4521-bdbb-14f4e336c30e"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   FractionBox["3", "4"], " ", "J2", " ", 
   SuperscriptBox["n0", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "-", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n0", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324659032118*^9},
 CellLabel->"Out[14]=",ExpressionUUID->"29fd7ced-f59d-42f1-b6dd-8d1a8d35cee9"]
}, Open  ]],

Cell[TextData[{
 "Now do the same for ",
 StyleBox["iterm", "Input"],
 "."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3f78701a-6167-4c6f-9242-584d41ab1c75"],

Cell[CellGroupData[{

Cell["\<\
Normal[Series[
iterm /. {n^2->n0^2*(1+(3/2)*J2*(Rp/a)^2-(15/8)*J4*(Rp/a)^4)},
{Rp,0,4}]]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[15]:=",ExpressionUUID->"eec8508f-e1a7-46a1-90ea-3da3336b05c0"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", 
    FractionBox["3", "4"]}], " ", "J2", " ", 
   SuperscriptBox["n0", "2"], " ", 
   SuperscriptBox["Rp", "2"]}], "+", 
  FractionBox[
   RowBox[{"15", " ", "J4", " ", 
    SuperscriptBox["n0", "2"], " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "2"]}]]}]], "Output",
 CellChangeTimes->{3.811324659075697*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"3eab66f1-ab94-4b9d-a166-b187c02aaddc"]
}, Open  ]],

Cell[TextData[{
 "Input the equations for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["n", "2"], TraditionalForm]],ExpressionUUID->
  "ac1e0438-e4cc-4646-8a5c-5192cb4e2b5e"],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Kappa]", "2"], TraditionalForm]],ExpressionUUID->
  "be2c07f2-6051-459c-aff6-ab5d9f196364"],
 " and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Mu]", "2"], TraditionalForm]],ExpressionUUID->
  "919a2a82-c69f-4654-8ce3-082bc9351e7b"],
 "given in Eqs.(6.244) to (6.246)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e95b623f-7f25-47c2-8044-0510caf40592"],

Cell["\<\
n2 = 
  (GM/a^3)*(1+(3/2)J2*(Rp/a)^2-(15/8)*J4*(Rp/a)^4);
ka2 =
  (GM/a^3)*(1-(3/2)J2*(Rp/a)^2+(45/8)*J4*(Rp/a)^4);
mu2 =
  (GM/a^3)*(1+(9/2)J2*(Rp/a)^2-(75/8)*J4*(Rp/a)^4);\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[16]:=",ExpressionUUID->"de3aa427-8b2b-4915-b275-004ce3c1541e"],

Cell["\<\
Now use Eq.(6.247) to derive the equation for the variation of the longitude \
of pericentre given in Eq.(6.256).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c2d8f6a4-4c1d-47be-b903-6dc311ace41c"],

Cell["\<\
\[CurlyPi]dot = 
Expand[Normal[Series[
Sqrt[n2]-Sqrt[ka2], {Rp,0,4}]]] /. GM->gmp;\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[19]:=",ExpressionUUID->"261b133d-e865-456f-813f-c17a6fd865f5"],

Cell[TextData[{
 "Ensure that ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    SuperscriptBox["n", "2"]], TraditionalForm]],ExpressionUUID->
  "4ece5e57-e61e-4335-82c5-1ab1de013413"],
 "is taken to be ",
 StyleBox["n",
  FontSlant->"Italic"],
 "  to get Eq.(6.256)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"363db9a2-6deb-4c4f-9f81-70b0812eb296"],

Cell[CellGroupData[{

Cell["Normal[Series[\[CurlyPi]dot, {Rp,0,4}]] /. Sqrt[n^2]->n", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[20]:=",ExpressionUUID->"c91ed6f2-5a19-466f-9cfe-eb7226ca0513"],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{"3", " ", "J2", " ", "n", " ", 
    SuperscriptBox["Rp", "2"]}], 
   RowBox[{"2", " ", 
    SuperscriptBox["a", "2"]}]], "-", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"3", " ", 
       SuperscriptBox["J2", "2"]}], "+", 
      RowBox[{"10", " ", "J4"}]}], ")"}], " ", "n", " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "4"]}]]}]], "Output",
 CellChangeTimes->{3.8113246592643147`*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"bf71117f-431f-47c6-88f7-ce6d1559ba95"]
}, Open  ]],

Cell["\<\
Now use Eq.(6.248) to derive the equation for the variation of the longitude \
of ascending node given in Eq.(6.257).\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b9baa910-ee74-473c-ae0c-4f7fa626cad9"],

Cell["\<\
\[CapitalOmega]dot = 
Expand[Normal[Series[
Sqrt[n2]-Sqrt[mu2], {Rp,0,4}]]] /. GM->gmp;\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[21]:=",ExpressionUUID->"a00ebae6-2b46-4334-9752-516ab515c52c"],

Cell[TextData[{
 "Ensure that ",
 Cell[BoxData[
  FormBox[
   SqrtBox[
    SuperscriptBox["n", "2"]], TraditionalForm]],ExpressionUUID->
  "ae9d7015-58b2-443e-9ff5-1979e0513fbe"],
 "is taken to be ",
 StyleBox["n",
  FontSlant->"Italic"],
 "  to get Eq.(6.257)."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"55b279a4-a804-4a9b-be69-2efd0fd5f303"],

Cell["Normal[Series[\[CapitalOmega]dot, {Rp,0,4}]] /. Sqrt[n^2]->n", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[22]:=",ExpressionUUID->"a76e961b-6444-416a-8a77-23ab20b524bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"3", " ", "J2", " ", "n", " ", 
     SuperscriptBox["Rp", "2"]}], 
    RowBox[{"2", " ", 
     SuperscriptBox["a", "2"]}]]}], "+", 
  FractionBox[
   RowBox[{"3", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"9", " ", 
       SuperscriptBox["J2", "2"]}], "+", 
      RowBox[{"10", " ", "J4"}]}], ")"}], " ", "n", " ", 
    SuperscriptBox["Rp", "4"]}], 
   RowBox[{"8", " ", 
    SuperscriptBox["a", "4"]}]]}]], "Output",
 CellChangeTimes->{3.8113246593243437`*^9},
 CellLabel->"Out[22]=",ExpressionUUID->"96cdf22d-ff84-4be5-9a13-450ba0830eed"]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{915, 482},
WindowMargins->{{50, Automatic}, {Automatic, 290}},
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"8256b013-d8e5-46bb-9aa7-46b2bd6db740"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 97, 0, 67, "Section",ExpressionUUID->"7caaa5d9-326a-481c-9bd0-4d8640893aea"],
Cell[658, 22, 265, 6, 49, "Text",ExpressionUUID->"65d60a7e-9249-443f-bdc0-d47eb406649d"],
Cell[CellGroupData[{
Cell[948, 32, 158, 2, 30, "Input",ExpressionUUID->"6e7d6b93-3fa0-4fd8-8131-3cdb364d2a09"],
Cell[1109, 36, 351, 10, 50, "Output",ExpressionUUID->"ccbecf64-e43e-4c63-99b1-d088ca42fe87"]
}, Open  ]],
Cell[1475, 49, 160, 3, 53, "Text",ExpressionUUID->"2d49be88-e574-4f44-b6fe-d06eac99ae02"],
Cell[CellGroupData[{
Cell[1660, 56, 158, 2, 30, "Input",ExpressionUUID->"0860c9c1-4ecd-4c7e-b2ea-cd6b4e834718"],
Cell[1821, 60, 436, 12, 51, "Output",ExpressionUUID->"d8a333b5-12e5-4cac-9e32-f875570d399e"]
}, Open  ]],
Cell[2272, 75, 212, 5, 53, "Text",ExpressionUUID->"c3061a05-3a49-404b-8deb-bd60c473c520"],
Cell[CellGroupData[{
Cell[2509, 84, 180, 2, 30, "Input",ExpressionUUID->"ba3dba41-dd3a-4ebe-bc05-173022f18487"],
Cell[2692, 88, 609, 17, 50, "Output",ExpressionUUID->"8dd1a26c-842f-4e9e-badb-1854f870cc92"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3338, 110, 180, 2, 30, "Input",ExpressionUUID->"ab6bcb1c-d47c-41a7-bdd3-634f7479a267"],
Cell[3521, 114, 1502, 44, 90, "Output",ExpressionUUID->"6ff42e85-3174-4fbb-ba8c-37a82353b469"]
}, Open  ]],
Cell[5038, 161, 372, 11, 56, "Text",ExpressionUUID->"51be784b-9377-4efe-bfa9-7a8562dcdfc0"],
Cell[CellGroupData[{
Cell[5435, 176, 236, 7, 84, "Input",ExpressionUUID->"bfefa771-aaf3-4708-8e39-6df0ea4596a7"],
Cell[5674, 185, 658, 20, 56, "Output",ExpressionUUID->"27e7f37f-4db6-4a66-97d7-1896fe2f62a4"]
}, Open  ]],
Cell[6347, 208, 234, 6, 53, "Text",ExpressionUUID->"107328aa-f9ff-4fd1-ad44-5cccff885735"],
Cell[6584, 216, 218, 6, 66, "Input",ExpressionUUID->"ae499171-16a5-41e4-a752-5f5d5663d391"],
Cell[6805, 224, 343, 11, 53, "Text",ExpressionUUID->"e18473ed-f6e3-4fed-8f7c-ca0a9011d71a"],
Cell[7151, 237, 260, 6, 66, "Input",ExpressionUUID->"9eb27eb7-49ac-4316-92cf-5344a1972a65"],
Cell[7414, 245, 289, 11, 53, "Text",ExpressionUUID->"19644444-e1cc-4164-b953-a33c31ead15a"],
Cell[7706, 258, 208, 5, 48, "Input",ExpressionUUID->"ff5dc4e4-ed9d-4524-ba45-805e49753b33"],
Cell[7917, 265, 376, 13, 56, "Text",ExpressionUUID->"d675f371-36b8-4f68-94ea-1a34afb111ac"],
Cell[CellGroupData[{
Cell[8318, 282, 143, 1, 30, "Input",ExpressionUUID->"50af5afb-b4fb-4daa-a5a2-c12debaff2b7"],
Cell[8464, 285, 6991, 216, 325, "Output",ExpressionUUID->"3f406dad-d171-4c1c-9a36-cee9708437a5"]
}, Open  ]],
Cell[15470, 504, 720, 22, 76, "Text",ExpressionUUID->"1240bea7-5e85-4685-80c3-6d4844ce7b2f"],
Cell[CellGroupData[{
Cell[16215, 530, 205, 6, 66, "Input",ExpressionUUID->"d824dfb7-6448-4910-b295-126518573e6a"],
Cell[16423, 538, 1905, 60, 100, "Output",ExpressionUUID->"30fe53ca-0b86-417f-a3ff-6fa2b5236683"]
}, Open  ]],
Cell[18343, 601, 347, 10, 53, "Text",ExpressionUUID->"33959b73-6e1e-4d7d-ba96-af4a5461cf15"],
Cell[CellGroupData[{
Cell[18715, 615, 161, 2, 30, "Input",ExpressionUUID->"12fe8563-f178-44aa-9d8b-3ff280a19146"],
Cell[18879, 619, 663, 20, 55, "Output",ExpressionUUID->"f19e5233-d0fe-4f6a-829f-e57f62e91b75"]
}, Open  ]],
Cell[19557, 642, 330, 10, 53, "Text",ExpressionUUID->"6a30b261-e286-43b8-9678-5e7dea15ce0d"],
Cell[CellGroupData[{
Cell[19912, 656, 162, 2, 30, "Input",ExpressionUUID->"9eb5dfdd-0f61-4682-aa5e-c6a64f7bf1d6"],
Cell[20077, 660, 683, 21, 55, "Output",ExpressionUUID->"30cb87f2-363a-442e-9033-25a97a035fcb"]
}, Open  ]],
Cell[20775, 684, 172, 3, 53, "Text",ExpressionUUID->"1d2ed81a-25e2-4a5a-87d1-64af5b3cd958"],
Cell[CellGroupData[{
Cell[20972, 691, 166, 2, 30, "Input",ExpressionUUID->"89285985-34ad-4317-8d33-366230d82ffd"],
Cell[21141, 695, 1406, 43, 55, "Output",ExpressionUUID->"48cef4c2-bdb9-4e45-8567-932a99a471bf"]
}, Open  ]],
Cell[22562, 741, 585, 18, 99, "Text",ExpressionUUID->"fad55690-c4de-49e1-adbb-f342d21684f0"],
Cell[CellGroupData[{
Cell[23172, 763, 224, 6, 66, "Input",ExpressionUUID->"800c0797-35ae-4521-bdbb-14f4e336c30e"],
Cell[23399, 771, 460, 13, 55, "Output",ExpressionUUID->"29fd7ced-f59d-42f1-b6dd-8d1a8d35cee9"]
}, Open  ]],
Cell[23874, 787, 196, 7, 53, "Text",ExpressionUUID->"3f78701a-6167-4c6f-9242-584d41ab1c75"],
Cell[CellGroupData[{
Cell[24095, 798, 224, 6, 66, "Input",ExpressionUUID->"eec8508f-e1a7-46a1-90ea-3da3336b05c0"],
Cell[24322, 806, 480, 14, 55, "Output",ExpressionUUID->"3eab66f1-ab94-4b9d-a166-b187c02aaddc"]
}, Open  ]],
Cell[24817, 823, 629, 20, 53, "Text",ExpressionUUID->"e95b623f-7f25-47c2-8044-0510caf40592"],
Cell[25449, 845, 309, 9, 120, "Input",ExpressionUUID->"de3aa427-8b2b-4915-b275-004ce3c1541e"],
Cell[25761, 856, 247, 6, 53, "Text",ExpressionUUID->"c2d8f6a4-4c1d-47be-b903-6dc311ace41c"],
Cell[26011, 864, 218, 6, 66, "Input",ExpressionUUID->"261b133d-e865-456f-813f-c17a6fd865f5"],
Cell[26232, 872, 384, 14, 56, "Text",ExpressionUUID->"363db9a2-6deb-4c4f-9f81-70b0812eb296"],
Cell[CellGroupData[{
Cell[26641, 890, 183, 2, 30, "Input",ExpressionUUID->"c91ed6f2-5a19-466f-9cfe-eb7226ca0513"],
Cell[26827, 894, 595, 18, 57, "Output",ExpressionUUID->"bf71117f-431f-47c6-88f7-ce6d1559ba95"]
}, Open  ]],
Cell[27437, 915, 251, 6, 53, "Text",ExpressionUUID->"b9baa910-ee74-473c-ae0c-4f7fa626cad9"],
Cell[27691, 923, 223, 6, 66, "Input",ExpressionUUID->"a00ebae6-2b46-4334-9752-516ab515c52c"],
Cell[27917, 931, 384, 14, 56, "Text",ExpressionUUID->"55b279a4-a804-4a9b-be69-2efd0fd5f303"],
Cell[28304, 947, 188, 2, 30, "Input",ExpressionUUID->"a76e961b-6444-416a-8a77-23ab20b524bd"],
Cell[28495, 951, 618, 19, 57, "Output",ExpressionUUID->"96cdf22d-ff84-4be5-9a13-450ba0830eed"]
}
]
*)

(* End of internal cache information *)

